Learn R Programming

ragt2ridges (version 0.1.9)

impulseResponseVAR1: Impulse response analysis of the VAR(1) model

Description

Evaluate the mean absolute impulse responses of the VAR(1) model. It assesses the effect of an innovation (error) at one time point on the variates at future time points. In the VAR(1) model this amounts to studying powers of $\mathbf{A}$, the matrix of regression coefficients.

Usage

impulseResponseVAR1(A, Tmax, figure=FALSE)

Arguments

A
A matrix $\mathbf{A}$ of regression parameters.
Tmax
Maximum number (positive numeric of length one) of time points up to which the impulse responses are to be evaluated.
figure
A logical, indicating whether a summary plot of the impulse responses should be generated.

Value

  • Object of class matrix. Rows correspond to covariates, columns to time points, and elements to the column-mean of the absolute impulse responses.

References

Hamilton, J. D. (1994), Time series analysis. Princeton: Princeton university press.

Lutkepohl, H. (2005), New Introduction to Multiple Time Series Analysis. Springer, Berlin.

See Also

ridgeVAR1.

Examples

Run this code
# set dimensions
p <- 3; n <- 4; T <- 10

# set model parameters
SigmaE <- diag(p)/4
A <- createA(p, "chain")

# generate data
Y <- dataVAR1(n, T, A, SigmaE)

# fit VAR(1) model
VAR1hat <- ridgeVAR1(Y, 1, 1)

# impulse response analysis
impulseResponseVAR1(VAR1hat$A, 10, figure=TRUE)

Run the code above in your browser using DataLab