Learn R Programming

ragt2ridges (version 0.1.9)

mutualInfoVAR1: Mutual information analysis of the VAR(1) model

Description

Evaluate, within the VAR(1) model, the mutual information between a variate at one time point and the variates at future time points.

Usage

mutualInfoVAR1(A, SigmaE, Tmax, figure=FALSE)

Arguments

A
A matrix $\mathbf{A}$ of auto-regression parameters.
SigmaE
Covariance matrix of the errors (innovations).
Tmax
Maximum number (positive numeric of length one) of time points up to which the mutual informations are to be evaluated.
figure
A logical, indicating whether a summary plot of the mutual informations should be generated.

Value

  • Object of class matrix. Rows correspond to covariates, columns to time points, and elements to the mutual informations.

References

Miok, V., Wilting, S.M., Van Wieringen, W.N. (2015), "Ridge estimation of the VAR(1) model and its time series chain graph from multivariate time-course omics data", submitted.

See Also

ridgeVAR1.

Examples

Run this code
# set dimensions
p <- 3; n <- 4; T <- 10

# set model parameters
SigmaE <- diag(p)/4
A <- createA(p, "chain")

# generate data
Y <- dataVAR1(n, T, A, SigmaE)

# fit VAR(1) model
VAR1hat <- ridgeVAR1(Y, 1, 1)

# impulse response analysis
mutualInfoVAR1(VAR1hat$A, solve(symm(VAR1hat$P)), 10, figure=TRUE)

Run the code above in your browser using DataLab