Ridge maximum likelihood estimation of vector auto-regressive processes and supporting functions for their exploitation. Currently, it includes:
Ridge estimation of the parameters of the first-order Vector Auto-Regressive model, commonly referred to as the VAR(1) model, through the function ridgeVAR1. This function is complemented by optPenaltyVAR1, a function for penalty parameters selection through leave-one-out cross-validation (with supporting functions loglikVAR1 and loglikLOOCVVAR1).
Functions for simulating VAR(1) data (createA and dataVAR1), data visualization (plotVAR1data), and some simple data manipulations (centerVAR1data, array2longitudinal, and longitudinal2array).
Ridge estimation of the precision matrix with known support (ridgePchordal, optPenaltyPchordal, and support4ridgeP).
Some diagnostics provided through evaluateVAR1fit, loglikLOOCVcontourVAR1, and ridgePathVAR1.
Several post-estimation analyses to exploit the fitted model. Among others: support determination of the VAR(1) model parameters (sparsifyVAR1), visualization of the (aspects of the) time-series chain graph (graphVAR1 and CIGofVAR1), and summary statistics per variate in terms of the VAR(1) model and its associated time-series chain graph (nodeStatsVAR1, impulseResponseVAR1, and mutualInfoVAR1).
Time-series omics data (hpvP53).
Future versions aim to include more functionality for time-series models.
The ragt2ridges-package is a sister-package to the rags2ridges-package, augmenting the latter 'base' package with functionality for time-course studies. Being its sibling ragt2ridges mimicks rags2ridges in the function names (compare e.g. ridgeP to ridgeVAR1). Moreover, some parts of the ragt2ridges-package not specific to time-series will probably be moved to the rags2ridges-package in the near future, e.g. momentS, ridgePchordal, optPenaltyPchordal, and support4ridgeP.
| Package: | ragt2ridges |
| Type: | Package |
| Version: | 0.1.15 |
| Date: | 2016-01-24 |
| License: | GPL (>= 2) |
Miok, V., Wilting, S.M., Van Wieringen, W.N. (2017), "Ridge estimation of the VAR(1) model and its time series chain graph from multivariate time-course omics data", Biometrical Journal, 59(1), 172-191.
The rags2ridges-package.