Learn R Programming

ragt2ridges (version 0.1.9)

ragt2ridges-package: Ridge Estimation of the Vector Auto-Regressive (VAR) Processes

Description

Ridge maximum likelihood estimation of vector auto-regressive processes and supporting functions for their exploitation. Currently, it includes: Future versions aim to include more functionality for time-series models.

The ragt2ridges-package is a sister-package to the rags2ridges-package, augmenting the latter 'base' package with functionality for time-course studies. Being its sibling ragt2ridges mimicks rags2ridges in the function names (compare e.g. ridgeP to ridgeVAR1). Moreover, some parts of the ragt2ridges-package not specific to time-series will be moved to the rags2ridges-package in the near future, e.g. ridgePchordal, optPenaltyPchordal, and support4ridgeP.

Arguments

Details

ll{ Package: ragt2ridges Type: Package Version: 0.1.15 Date: 2016-01-24 License: GPL (>= 2) }

References

Miok, V., Wilting, S.M., Van Wieringen, W.N. (2015), "Ridge estimation of the VAR(1) model and its time series chain graph from multivariate time-course omics data", submitted.

See Also

The rags2ridges-package.